@@ -21,6 +21,7 @@ use File::Which;
 use File::Path qw(make_path);
 use Cwd qw(abs_path getcwd);
 use File::Temp;
+use File::Basename;
 extends 'Bio::Roary::CommandLine::Common';
 
 has 'args'        => ( is => 'ro', isa => 'ArrayRef', required => 1 );
@@ -41,6 +42,7 @@ has 'cpus'                    => ( is => 'rw', isa => 'Int',  default => 1 );
 has 'output_multifasta_files' => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'perc_identity'           => ( is => 'rw', isa => 'Num',  default => 95 );
 has 'dont_delete_files'       => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'check_dependancies'      => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'dont_create_rplots'      => ( is => 'rw', isa => 'Bool', default => 1 );
 has 'dont_run_qc'             => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'dont_split_groups'       => ( is => 'rw', isa => 'Bool', default => 0 );
@@ -120,23 +122,41 @@ sub BUILD {
 	Pubmed: 26198102\n\n";
 
     $self->help($help) if ( defined($help) );
-    if( $self->help ) 
+    if( $self->help )
 	{
 		print $self->usage_text;
 		return;
 	}
-
-    if ($check_dependancies) {
-        my $check_tools = Bio::Roary::External::CheckTools->new();
-        $check_tools->check_all_tools;
-        $self->logger->error( "Roary version " . $self->_version() );
-    }
-
+	
     if ( defined($verbose) ) {
         $self->verbose($verbose);
         $self->logger->level(10000);
     }
 
+	$self->check_dependancies($check_dependancies) if ( defined($check_dependancies) );
+    if ($self->check_dependancies) {
+        my $check_tools = Bio::Roary::External::CheckTools->new();
+        $check_tools->check_all_tools;
+        $self->logger->error( "Roary version " . $self->_version() );
+		
+		if( @{ $self->args } < 1 )
+		{
+			return;
+		}
+    }
+
+    if ( @{ $self->args } < 2 ) {
+        $self->logger->error("Error: You need to provide at least 2 files to build a pan genome");
+        die $self->usage_text;
+    }
+    my %basenames;
+    foreach my $string (@{$self->args}) {
+	my($base, $path, $suf) = fileparse($string);
+	next unless $basenames{$base}++;
+        $self->logger->error("Error: GFF files must have unique basenames.");
+        die $self->usage_text;
+    }
+
     if ( @{ $self->args } < 2 ) {
         $self->logger->error("Error: You need to provide at least 2 files to build a pan genome");
         die $self->usage_text;
@@ -154,7 +174,7 @@ sub BUILD {
         $self->perc_identity($perc_identity);
         if ( $perc_identity < 50 ) {
             $self->logger->error(
-"The percentage identity is too low. Either somethings wrong with your data, like contamination, or your doing something that the software isnt designed to support."
+"The percentage identity is too low. Either something is wrong with your data, like contamination, or your doing something that the software isnt designed to support."
             );
         }
     }
@@ -246,8 +266,8 @@ sub _setup_output_directory {
 
 sub run {
     my ($self) = @_;
-	
-	return if($self->version || $self->help);
+
+	return if($self->version || $self->help || ($self->check_dependancies && @{$self->fasta_files} < 1) );
 
     $self->_setup_output_directory;
 
